Learn R Programming

ethnobotanyR (version 0.2.0)

CIs: Cultural Importance index (CI)

Description

Calculates the Cultural Importance Index (CI) per species.

Usage

CIs(data)

Arguments

Value

Data frame of species and Cultural Importance Index (CI) values.

References

Tardio, Javier, and Manuel Pardo-de-Santayana. 2008. “Cultural Importance Indices: A Comparative Analysis Based on the Useful Wild Plants of Southern Cantabria (Northern Spain) 1.” Economic Botany 62 (1): 24–39.

Whitney, C. W., Bahati, J., and Gebauer, J. (2018), Ethnobotany and agrobiodiversity; valuation of plants in the homegardens of southwestern Uganda. Ethnobiology Letters, 9(2), 90-100. tools:::Rd_expr_doi("10.14237/ebl.9.2.2018.503")

Examples

Run this code

#Use built-in ethnobotany data example
CIs(ethnobotanydata)

#Generate random dataset of three informants uses for four species

eb_data <- data.frame(replicate(10,sample(0:1,20,rep=TRUE)))
names(eb_data) <- gsub(x = names(eb_data), pattern = "X", replacement = "Use_")  
eb_data$informant <- sample(c('User_1', 'User_2', 'User_3'), 20, replace=TRUE)
eb_data$sp_name <- sample(c('sp_1', 'sp_2', 'sp_3', 'sp_4'), 20, replace=TRUE)

CIs(eb_data)

Run the code above in your browser using DataLab